Enum native_windows_gui::ControlHandle [−][src]
pub enum ControlHandle {
NoHandle,
Hwnd(HWND),
Menu(HMENU, HMENU),
PopMenu(HWND, HMENU),
MenuItem(HMENU, u32),
Notice(HWND, u32),
Timer(HWND, u32),
SystemTray(HWND),
}Inner handle type used internally by each control.
Variants
Hwnd(HWND)(Parent menu / Menu). Parent menu must be there as WINAPI does not have any function to fetch the parent
(Parent window / Menu).
(Parent menu / Unique ID).
Notice control
Timer control
SystemTray(HWND)System tray control
Implementations
impl ControlHandle[src]
pub fn destroy(&mut self)[src]
Destroy the underlying object and set the handle to NoHandle
Can be used to “reset” a UI component
pub fn blank(&self) -> bool[src]
pub fn hwnd(&self) -> Option<HWND>[src]
pub fn hmenu(&self) -> Option<(HMENU, HMENU)>[src]
pub fn pop_hmenu(&self) -> Option<(HWND, HMENU)>[src]
pub fn hmenu_item(&self) -> Option<(HMENU, u32)>[src]
pub fn timer(&self) -> Option<(HWND, u32)>[src]
pub fn notice(&self) -> Option<(HWND, u32)>[src]
pub fn tray(&self) -> Option<HWND>[src]