Enum native_windows_gui::ParaNumberingStyle[][src]

pub enum ParaNumberingStyle {
    Paren,
    Parens,
    Period,
    Plain,
    NoNumber,
    NewNumber,
}
Numbering style used with the numbering paragraphs. Used with ParamNumbering

Variants

Paren

Follows the number with a right parenthesis

Parens

Encloses the number in parentheses

Period

Follows the number with a period

Plain

Display only the number

NoNumber

Continues a numbered lsit without applying the next number of bullet

NewNumber

Starts a new number using the value of ParaNumbering::Seq(char)