Struct native_windows_gui::CharFormat [−][src]
pub struct CharFormat {
pub effects: Option<CharEffects>,
pub height: Option<i32>,
pub y_offset: Option<i32>,
pub text_color: Option<[u8; 3]>,
pub font_face_name: Option<String>,
pub underline_type: Option<UnderlineType>,
}Contains information about character formatting in a rich edit control
Fields
effects: Option<CharEffects>Character effects (bold, italics, strikeout, etc)
When returned by char_format, specifies which attributes are consistent throughout the entire selection.
For example, if the entire selection is either in italics or not in italics.
height: Option<i32>Character height, in twips (1/1440 of an inch or 1/20 of a printer’s point).
y_offset: Option<i32>Character offset, in twips, from the baseline. If the value of this member is positive, the character is a superscript; if it is negative, the character is a subscript.
text_color: Option<[u8; 3]>Text color. This member is ignored if the AUTOCOLOR character effect is specified.
font_face_name: Option<String>The font family name
underline_type: Option<UnderlineType>Text underline type. Does not work with effects