Struct native_windows_gui::Cursor[][src]

pub struct Cursor {
    pub handle: HANDLE,
    // some fields omitted
}

A wrapper over a cursor file (*.cur)

Cursor resources can be used with the cursor feature

Example:

use native_windows_gui as nwg;

fn load_cursor() -> nwg::Cursor {
    nwg::Cursor::from_file("Hello.cur", true).unwrap()
}

fn load_cursor_builder() -> nwg::Cursor {
    let mut cursor = nwg::Cursor::default();

    nwg::Cursor::builder()
        .source_file(Some("Hello.cur"))
        .strict(true)
        .build(&mut cursor)
        .unwrap();

    cursor
}

Fields

handle: HANDLE

Implementations

impl Cursor[src]

pub fn builder<'a>() -> CursorBuilder<'a>[src]

pub fn from_system(cursor: OemCursor) -> Cursor[src]

pub fn from_file(path: &str, strict: bool) -> Result<Cursor, NwgError>[src]

Single line helper function over the cursor builder api.

Use a file resource.

pub fn from_embed(
    embed: &EmbedResource,
    embed_id: Option<usize>,
    embed_str: Option<&str>
) -> Result<Cursor, NwgError>
[src]

Single line helper function over the cursor builder api.

Use an embedded resource. Either embed_id or embed_str must be defined, not both.

Requires the embed-resource feature.