[−][src]Struct native_windows_gui::DropFiles
Opaque type over one or more dragged files.
Implementations
impl DropFiles[src]
pub fn point(&self) -> [i32; 2][src]
Retrieves the position of the mouse pointer at the time a file was dropped during a drag-and-drop operation. The coordinates are local to the control. Ex: (0, 0) is the top left corner of the control.
pub fn len(&self) -> usize[src]
Return the number of files dropped
pub fn files(&self) -> Vec<String>[src]
Return the files path dropped into the app