[−][src]Struct native_windows_gui::DynLayoutBuilder
Builder for a DynLayout struct
Implementations
impl DynLayoutBuilder[src]
pub fn parent<W: Into<ControlHandle>>(mut self: Self, p: W) -> DynLayoutBuilder[src]
Set the layout parent. The handle must be a window object otherwise the function will panic
pub fn child<W: Into<ControlHandle>>(
mut self: Self,
m: (i32, i32),
s: (i32, i32),
c: W
) -> DynLayoutBuilder[src]
mut self: Self,
m: (i32, i32),
s: (i32, i32),
c: W
) -> DynLayoutBuilder
Add a children to the layout at the position col and row.
This is a shortcut over child_item for item with default span.
The handle must be a window object otherwise the function will panic
pub fn child_item(mut self: Self, item: DynLayoutItem) -> DynLayoutBuilder[src]
Add a children to the layout The handle must be a window object otherwise the function will panic
pub fn build(self, layout: &DynLayout) -> Result<(), NwgError>[src]
Build the layout object and bind the callback. Children must only contains window object otherwise this method will panic.