Struct native_windows_gui::DynLayoutInner [−][src]
pub struct DynLayoutInner { /* fields omitted */ }A layout that lays out widgets This is the inner data shared between the callback and the application