[][src]Struct native_windows_gui::FlexboxLayoutBuilder

pub struct FlexboxLayoutBuilder { /* fields omitted */ }

Implementations

impl FlexboxLayoutBuilder[src]

pub fn parent<W: Into<ControlHandle>>(
    mut self: Self,
    p: W
) -> FlexboxLayoutBuilder
[src]

Set the layout parent. The handle must be a window object otherwise the function will panic

pub fn child<W: Into<ControlHandle>>(
    mut self: Self,
    child: W
) -> FlexboxLayoutBuilder
[src]

Add a new child to the layout build. Panics if child is not a window-like control.

pub fn auto_size(mut self: Self, auto: bool) -> FlexboxLayoutBuilder[src]

Make it so that the children of the layout all have equal size This flags is erased when size, max_size, or min_size is set on the children.

pub fn auto_spacing(mut self: Self, auto: Option<u32>) -> FlexboxLayoutBuilder[src]

Automatically generate padding and margin for the parent layout and the children from the selected value. This flags is erased when padding is called on the layout or when child_margin is called on the children

pub fn direction(mut self: Self, value: Direction) -> FlexboxLayoutBuilder[src]

pub fn flex_direction(
    mut self: Self,
    value: FlexDirection
) -> FlexboxLayoutBuilder
[src]

pub fn flex_wrap(mut self: Self, value: FlexWrap) -> FlexboxLayoutBuilder[src]

pub fn overflow(mut self: Self, value: Overflow) -> FlexboxLayoutBuilder[src]

pub fn align_items(mut self: Self, value: AlignItems) -> FlexboxLayoutBuilder[src]

pub fn align_content(
    mut self: Self,
    value: AlignContent
) -> FlexboxLayoutBuilder
[src]

pub fn justify_content(
    mut self: Self,
    value: JustifyContent
) -> FlexboxLayoutBuilder
[src]

pub fn padding(mut self: Self, value: Rect<Dimension>) -> FlexboxLayoutBuilder[src]

pub fn border(mut self: Self, value: Rect<Dimension>) -> FlexboxLayoutBuilder[src]

pub fn min_size(mut self: Self, value: Size<Dimension>) -> FlexboxLayoutBuilder[src]

pub fn max_size(mut self: Self, value: Size<Dimension>) -> FlexboxLayoutBuilder[src]

pub fn aspect_ratio(mut self: Self, value: Number) -> FlexboxLayoutBuilder[src]

pub fn child_size(mut self: Self, size: Size<Dimension>) -> FlexboxLayoutBuilder[src]

Set the size of of the current child. Panics if child was not called before.

pub fn child_position(
    mut self: Self,
    position: Rect<Dimension>
) -> FlexboxLayoutBuilder
[src]

Set the position of the current child. Panics if child was not called before.

pub fn child_margin(
    mut self: Self,
    value: Rect<Dimension>
) -> FlexboxLayoutBuilder
[src]

Set the margin of the current child. Panics if child was not called before.

pub fn child_min_size(
    mut self: Self,
    value: Size<Dimension>
) -> FlexboxLayoutBuilder
[src]

Set the min size of the current child. Panics if child was not called before.

pub fn child_max_size(
    mut self: Self,
    value: Size<Dimension>
) -> FlexboxLayoutBuilder
[src]

Set the max size of the current child. Panics if child was not called before.

pub fn child_flex_grow(mut self: Self, value: f32) -> FlexboxLayoutBuilder[src]

Panics if child was not called before.

pub fn child_flex_shrink(mut self: Self, value: f32) -> FlexboxLayoutBuilder[src]

Panics if child was not called before.

pub fn child_flex_basis(
    mut self: Self,
    value: Dimension
) -> FlexboxLayoutBuilder
[src]

Panics if child was not called before.

pub fn child_align_self(
    mut self: Self,
    value: AlignSelf
) -> FlexboxLayoutBuilder
[src]

Panics if child was not called before.

pub fn style(mut self: Self, style: Style) -> FlexboxLayoutBuilder[src]

Directly set the style parameter of the current child. Panics if child was not called before.

If defining style is too verbose, other method such as size can be used.

pub fn build(mut self: Self, layout: &FlexboxLayout) -> Result<(), NwgError>[src]

Build the layout object and bind the callback. Children must only contains window object otherwise this method will panic.