Font

Struct Font 

pub struct Font {
    pub handle: HFONT,
}
Represent a system font.

Can be used with any controls that draws text. Due to the very limited way win32 can draw text, only family, size and weight can be configured.

Example:

use native_windows_gui as nwg;

fn build_font() -> nwg::Font {
    let mut font = nwg::Font::default();

    nwg::Font::builder()
        .size(16)
        .family("Arial")
        .weight(1000)
        .build(&mut font);

    font
}

Fields

handle: HFONT

Implementations

Source

impl Font

pub fn builder<'a>() -> FontBuilder<'a>

pub fn set_global_default(font: Option<Font>) -> Option<Font>

Set the default (application global!) font that will be used when creating controls and return the old one

pub fn set_global_family(family: &str) -> Result<Option<Font>, NwgError>

Set the default (application global!) font that will be used when creating controls This is a shortcut over Font::set_global_default

Examples found in repository?
examples/basic.rs (line 123)
121fn main() {
122    nwg::init().expect("Failed to init Native Windows GUI");
123    nwg::Font::set_global_family("Segoe UI").expect("Failed to set default font");
124    let _ui = BasicApp::build_ui(Default::default()).expect("Failed to build UI");
125    nwg::dispatch_thread_events();
126}
More examples
Hide additional examples
examples/basic_layout.rs (line 128)
126fn main() {
127    nwg::init().expect("Failed to init Native Windows GUI");
128    nwg::Font::set_global_family("Segoe UI").expect("Failed to set default font");
129    let _ui = BasicApp::build_ui(Default::default()).expect("Failed to build UI");
130    nwg::dispatch_thread_events();
131}
examples/calculator.rs (line 283)
281fn main() {
282    nwg::init().expect("Failed to init Native Windows GUI");
283    nwg::Font::set_global_family("Segoe UI").expect("Failed to set default font");
284
285    let _app = Calculator::build_ui(Default::default()).expect("Failed to build UI");
286    nwg::dispatch_thread_events();
287}
examples/message_bank.rs (line 182)
180fn main() {
181    nwg::init().expect("Failed to init Native Windows GUI");
182    nwg::Font::set_global_family("Segoe UI").expect("Failed to set default font");
183
184    let _ui = MessageBank::build_ui(Default::default()).expect("Failed to build UI");
185    nwg::dispatch_thread_events();
186}
examples/flexbox.rs (line 144)
142fn main() {
143    nwg::init().expect("Failed to init Native Windows GUI");
144    nwg::Font::set_global_family("Segoe UI").expect("Failed to set default font");
145
146    let _ui = FlexBoxApp::build_ui(Default::default()).expect("Failed to build UI");
147    
148    nwg::dispatch_thread_events();
149}
examples/flexbox_sub_layout.rs (line 145)
143fn main() {
144    nwg::init().expect("Failed to init Native Windows GUI");
145    nwg::Font::set_global_family("Segoe UI").expect("Failed to set default font");
146
147    let _ui = FlexBoxApp::build_ui(Default::default()).expect("Failed to build UI");
148    
149    nwg::dispatch_thread_events();
150}
pub fn global_default() -> Option<Font>

Return the default font that was previously set using Font::set_default

pub fn add_font(path: &str) -> bool

Add a font to the system font table. Don’t forget to call Font::remove_font(path) once you’re done. Returns false if the font could not be added. Windows won’t tell you why though.

Other info:

  • The value of path can be a ttf or a otf font.
  • Adding the same font multiple time increase the internal refcount
  • Use Font::families() to return the available system font families
pub fn remove_font(path: &str)

Remove a font that was previously added by Font::add_font

pub fn add_memory_font(bin: &mut [u8]) -> Result<MemFont, ()>

Add a font resource from a binary source. Returns a memory font handle if the font was loaded succesfully. Send the handle to remove_memory_font at the end of your program to free the font from memory.

pub fn remove_memory_font(font: MemFont)

Remove a font that was previously added by Font::add_memory_font

pub fn families() -> Vec<String>

Returns all the font families loaded on the OS. Probably pretty slow, so cache the value if possible