[−][src]Struct native_windows_gui::FontInfo
Represent a font parameters. Returned by the font dialog when the user selected a font.
Can also be used to create a Font resource using Font::from_info
For more information on the parameters see: https://docs.microsoft.com/en-us/windows/win32/api/wingdi/ns-wingdi-logfonta
Fields
point_size: u32The size of the selected font, in units of 1/10 of a point
height: i32Specifies the height, in logical units, of the font's character cell or character.
width: i32Specifies the width, in logical units, of characters in the font.
escapement: i32Contains the angle, in tenths of degrees, between the escapement vector and the x-axis of the device. The escapement vector is parallel to the base line of a row of text.
orientation: i32Specifies the angle, in tenths of degrees, between each character's base line and the x-axis of the device.
weight: i32Specifies the weight of the font in the range from 0 through 1000.
italic: boolSpecifies an italic font if set to TRUE
underline: boolSpecifies an underlined font if set to TRUE.
strike_out: boolSpecifies a strikeout font if set to TRUE.
char_set: u8Specifies the character set.
out_precision: u8Specifies the output precision. The output precision defines how closely the output must match the requested font's height, width, character orientation, escapement, pitch, and font type.
clip_precision: u8specifies the clipping precision. The clipping precision defines how to clip characters that are partially outside the clipping region.
quality: u8specifies the output quality. The output quality defines how carefully the GDI must attempt to match the logical-font attributes to those of an actual physical font.
pitch_and_family: u8Specifies the pitch and family of the font.
name: StringContains a null-terminated string that specifies the typeface name of the font.