[−][src]Struct native_windows_gui::GridLayoutBuilder
Builder for a GridLayout struct
Implementations
impl GridLayoutBuilder[src]
pub fn parent<W: Into<ControlHandle>>(mut self: Self, p: W) -> GridLayoutBuilder[src]
Set the layout parent. The handle must be a window object otherwise the function will panic
pub fn child<W: Into<ControlHandle>>(
mut self: Self,
col: u32,
row: u32,
c: W
) -> GridLayoutBuilder[src]
mut self: Self,
col: u32,
row: u32,
c: W
) -> GridLayoutBuilder
Add a children to the layout at the position col and row.
This is a shortcut over child_item for item with default span.
The handle must be a window object otherwise the function will panic
pub fn child_item(mut self: Self, item: GridLayoutItem) -> GridLayoutBuilder[src]
Add a children to the layout The handle must be a window object otherwise the function will panic
pub fn margin(mut self: Self, m: [u32; 4]) -> GridLayoutBuilder[src]
Set the margins of the layout. The four values are in this order: top, right, bottom, left.
pub fn spacing(mut self: Self, sp: u32) -> GridLayoutBuilder[src]
Set the size of the space between the children in the layout. Default value is 5.
pub fn min_size(mut self: Self, sz: [u32; 2]) -> GridLayoutBuilder[src]
Sets the minimum size of the layout
pub fn max_size(mut self: Self, sz: [u32; 2]) -> GridLayoutBuilder[src]
Sets the maximum size of the layout
pub fn max_column(mut self: Self, count: Option<u32>) -> GridLayoutBuilder[src]
Set the number of column in the layout
pub fn max_row(mut self: Self, count: Option<u32>) -> GridLayoutBuilder[src]
Set the number of row in the layout
pub fn build(self, layout: &GridLayout) -> Result<(), NwgError>[src]
Build the layout object and bind the callback. Children must only contains window object otherwise this method will panic.