Struct native_windows_gui::HmenuBuilder [−][src]
pub struct HmenuBuilder { /* fields omitted */ }Expand description
Low level HMENU builder. Instanced by ControlBase::build_hmenu.
Implementations
Set the text of the Menu
Set if the menu should be an item or a menu
Set if the menu item should be a separator
Set if the menu item should be a separator
Set the parent of the menu. Can be a window or another menu.