Struct native_windows_gui::PopupMenuFlags[][src]

pub struct PopupMenuFlags { /* fields omitted */ }

Menu flags to use with the Menu::popup_with_flags function. Using PopupMenuFlags::empty is the same as ALIGN_LEFT|ALIGN_TOP|LEFT_BUTTON

Aligment flags:

  • ALIGN_LEFT: Positions the shortcut menu so that its left side is aligned with the coordinate specified by the x parameter.
  • ALIGN_H_CENTER: Centers the shortcut menu horizontally relative to the coordinate specified by the x parameter.
  • ALIGN_RIGHT: Positions the shortcut menu so that its right side is aligned with the coordinate specified by the x parameter.
  • ALIGN_BOTTOM: Positions the shortcut menu so that its bottom side is aligned with the coordinate specified by the y parameter.
  • ALIGN_TOP: Positions the shortcut menu so that its top side is aligned with the coordinate specified by the y parameter.
  • ALIGN_V_CENTER: Centers the shortcut menu vertically relative to the coordinate specified by the y parameter.

Button flags:

  • LEFT_BUTTON: The user can select menu items with only the left mouse button.
  • RIGHT_BUTTON: The user can select menu items with both the left AND right mouse buttons.

Animations flags:

  • ANIMATE_NONE: Displays menu without animation.
  • ANIMATE_RIGHT_TO_LEFT: Animates the menu from right to left.
  • ANIMATE_LEFT_TO_RIGHT: Animates the menu from left to right.
  • ANIMATE_BOTTOM_TO_TOP: Animates the menu from bottom to top.
  • ANIMATE_TOP_TO_BOTTOM: Animates the menu from top to bottom.

Implementations

impl PopupMenuFlags[src]

pub const ALIGN_LEFT: PopupMenuFlags[src]

pub const ALIGN_H_CENTER: PopupMenuFlags[src]

pub const ALIGN_RIGHT: PopupMenuFlags[src]

pub const ALIGN_BOTTOM: PopupMenuFlags[src]

pub const ALIGN_TOP: PopupMenuFlags[src]

pub const ALIGN_V_CENTER: PopupMenuFlags[src]

pub const LEFT_BUTTON: PopupMenuFlags[src]

pub const RIGHT_BUTTON: PopupMenuFlags[src]

pub const ANIMATE_NONE: PopupMenuFlags[src]

pub const ANIMATE_RIGHT_TO_LEFT: PopupMenuFlags[src]

pub const ANIMATE_LEFT_TO_RIGHT: PopupMenuFlags[src]

pub const ANIMATE_BOTTOM_TO_TOP: PopupMenuFlags[src]

pub const ANIMATE_TOP_TO_BOTTOM: PopupMenuFlags[src]

pub const fn empty() -> PopupMenuFlags[src]

Returns an empty set of flags

pub const fn all() -> PopupMenuFlags[src]

Returns the set containing all flags.

pub const fn bits(&self) -> u32[src]

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<PopupMenuFlags>[src]

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> PopupMenuFlags[src]

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> PopupMenuFlags[src]

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool[src]

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool[src]

Returns true if all flags are currently set.

pub const fn intersects(&self, other: PopupMenuFlags) -> bool[src]

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: PopupMenuFlags) -> bool[src]

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: PopupMenuFlags)[src]

Inserts the specified flags in-place.

pub fn remove(&mut self, other: PopupMenuFlags)[src]

Removes the specified flags in-place.

pub fn toggle(&mut self, other: PopupMenuFlags)[src]

Toggles the specified flags in-place.

pub fn set(&mut self, other: PopupMenuFlags, value: bool)[src]

Inserts or removes the specified flags depending on the passed value.