Struct native_windows_gui::RichLabel[][src]

pub struct RichLabel {
    pub handle: ControlHandle,
    // some fields omitted
}

A rich label is a label that supports rich text. This control is built on top of the rich text box control and as such require the rich-textbox feature. Enable “MULTI_LINE” to support multi line labels.

Unlike the basic Label, this version supports:

  • Colored text
  • Multiple fonts
  • Styled text such as bold, underscore, strikeout, etc
  • Bullet point list
  • Paragraph with custom indent/offset
  • Custom line spacing

Builder parameters:

  • parent: Required. The label parent container.
  • text: The label text.
  • size: The label size.
  • position: The label position.
  • enabled: If the label is enabled. A disabled label won’t trigger events
  • flags: A combination of the LabelFlags values.
  • ex_flags: A combination of win32 window extended flags. Unlike flags, ex_flags must be used straight from winapi
  • font: The font used for the label text
  • background_color: The background color of the label
  • h_align: The horizontal aligment of the label.
  • line_height: The line height in pixels for the vertical aligment. Can be None to disable vertical aligment. Real line height cannot be guessed by NWG due to the text formatting

Control events:

  • MousePress(_): Generic mouse press events on the label
  • OnMouseMove: Generic mouse mouse event
  • OnMouseWheel: Generic mouse wheel event

** Example **

use native_windows_gui as nwg;
fn build_label(label: &mut nwg::RichLabel, window: &nwg::Window, font: &nwg::Font) {
    nwg::RichLabel::builder()
        .text("Hello")
        .font(Some(font))
        .parent(window)
        .build(label);
}

Fields

handle: ControlHandle

Implementations

impl RichLabel[src]

pub fn builder<'a>() -> RichLabelBuilder<'a>[src]

pub fn set_background_color(&self, color: [u8; 3])[src]

Sets the background color for a rich edit control. You cannot get the background color of a rich label

pub fn set_char_format(&self, r: Range<u32>, fmt: &CharFormat)[src]

Sets the character format of the selected range of text

pub fn char_format(&self, r: Range<u32>) -> CharFormat[src]

Returns the character format of the selected range of text

pub fn set_para_format(&self, r: Range<u32>, fmt: &ParaFormat)[src]

Sets the paragraph formatting for the selected range of text in a rich edit control

pub fn para_format(&self, r: Range<u32>) -> ParaFormat[src]

Returns the paragraph formatting for the selected range of text in a rich edit control If more than one paragraph is selected, receive the attributes of the first paragraph

pub fn len(&self) -> u32[src]

Return the length of the user input in the control. This is better than control.text().len() as it does not allocate a string in memory

pub fn clear(&self)[src]

Remove all text from the textbox

pub fn set_line_height(&self, height: Option<i32>)[src]

Sets the line height for the vertical alignment

pub fn line_height(&self) -> Option<i32>[src]

Returns the line height for the vertical alignment

pub fn set_font(&self, font: Option<&Font>)[src]

Set base font of the control It is not possible to get the base font handle of a rich label. Use char_format instead.

pub fn visible(&self) -> bool[src]

Return true if the control is visible to the user. Will return true even if the control is outside of the parent client view (ex: at the position (10000, 10000))

pub fn set_visible(&self, v: bool)[src]

Show or hide the control to the user

pub fn size(&self) -> (u32, u32)[src]

Return the size of the button in the parent window

pub fn set_size(&self, x: u32, y: u32)[src]

Set the size of the button in the parent window

pub fn position(&self) -> (i32, i32)[src]

Return the position of the button in the parent window

pub fn set_position(&self, x: i32, y: i32)[src]

Set the position of the button in the parent window

pub fn text(&self) -> String[src]

Return the text displayed in the TextInput

pub fn set_text<'a>(&self, v: &'a str)[src]

Set the text displayed in the TextInput

pub fn class_name(&self) -> &'static str[src]

Winapi class name used during control creation

pub fn flags(&self) -> u32[src]

Winapi base flags used during window creation

pub fn forced_flags(&self) -> u32[src]

Winapi flags required by the control