[−][src]Struct native_windows_gui::ToolTipTextData
A wrapper structure that sets the tooltip text on an OnTooltipText callback
Implementations
impl ToolTipTextData[src]
pub fn keep(&self, keep: bool)[src]
Tells the application to save the text value of the callback
The OnTooltipText will not be called a second time for the associated control
pub fn set_text<'b>(&self, text: &'b str)[src]
Sets the text of the callback. This function will copy the text. WINAPI does not easily allow tooltips with more than 79 characters (80 with NULL) With a text > 79 characters, this method will do nothing.