[][src]Struct native_windows_gui::TrayNotificationBuilder

pub struct TrayNotificationBuilder<'a> { /* fields omitted */ }

Implementations

impl<'a> TrayNotificationBuilder<'a>[src]

pub fn parent<C: Into<ControlHandle>>(
    mut self: Self,
    p: C
) -> TrayNotificationBuilder<'a>
[src]

pub fn icon(
    mut self: Self,
    ico: Option<&'a Icon>
) -> TrayNotificationBuilder<'a>
[src]

pub fn realtime(mut self: Self, r: bool) -> TrayNotificationBuilder<'a>[src]

pub fn callback(mut self: Self, cb: bool) -> TrayNotificationBuilder<'a>[src]

pub fn visible(mut self: Self, v: bool) -> TrayNotificationBuilder<'a>[src]

pub fn balloon_icon(
    mut self: Self,
    ico: Option<&'a Icon>
) -> TrayNotificationBuilder<'a>
[src]

Note: balloon_icon is only used if info is set AND flags uses USER_ICON

pub fn flags(
    mut self: Self,
    flags: TrayNotificationFlags
) -> TrayNotificationBuilder<'a>
[src]

Note: flags are only used if info is set

pub fn tip(mut self: Self, tip: Option<&'a str>) -> TrayNotificationBuilder<'a>[src]

Note: tip will be truncated to 127 characters

pub fn info(
    mut self: Self,
    info: Option<&'a str>
) -> TrayNotificationBuilder<'a>
[src]

Note: info will be truncated to 255 characters

pub fn info_title(
    mut self: Self,
    title: Option<&'a str>
) -> TrayNotificationBuilder<'a>
[src]

Note: info will be truncated to 63 characters Note 2: This value is only used if info is also specified

pub fn build(self, out: &mut TrayNotification) -> Result<(), NwgError>[src]