[−][src]Struct native_windows_gui::WindowCloseData
Opaque type that manages if a window should be closed after an OnClose event
Implementations
impl WindowCloseData[src]
pub fn close(&self, value: bool)[src]
Sets if the window should close after the event
pub fn closing(&self) -> bool[src]
Returns true if the window will close after the event or false otherwise