Enum native_windows_gui::ParaNumberingStyle [−][src]
pub enum ParaNumberingStyle {
Paren,
Parens,
Period,
Plain,
NoNumber,
NewNumber,
}Expand description
Numbering style used with the numbering paragraphs. Used with ParamNumbering
Variants
Follows the number with a right parenthesis
Encloses the number in parentheses
Follows the number with a period
Display only the number
Continues a numbered lsit without applying the next number of bullet
Starts a new number using the value of ParaNumbering::Seq(char)