Struct native_windows_gui::CharEffects [−][src]
pub struct CharEffects { /* fields omitted */ }The effets that can be applied to the text of a rich edit control
- BOLD: Characters are bold.
- ITALIC: Characters are italic.
- STRIKEOUT: Characters are struck.
- UNDERLINE: Characters are underlined.
- AUTOCOLOR: Characters use the default system color
Implementations
impl CharEffects[src]
pub const BOLD: CharEffects[src]
pub const ITALIC: CharEffects[src]
pub const UNDERLINE: CharEffects[src]
pub const STRIKEOUT: CharEffects[src]
pub const AUTOCOLOR: CharEffects[src]
pub const fn empty() -> CharEffects[src]
Returns an empty set of flags
pub const fn all() -> CharEffects[src]
Returns the set containing all flags.
pub const fn bits(&self) -> u32[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<CharEffects>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u32) -> CharEffects[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u32) -> CharEffects[src]
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
pub const fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub const fn intersects(&self, other: CharEffects) -> bool[src]
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: CharEffects) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: CharEffects)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: CharEffects)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: CharEffects)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: CharEffects, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.